==> owncloud-10.2.0.zip: owncloud/apps/files_sharing/l10n/ru.js <==
OC.L10N.register(
    "files_sharing",
    {
    "Server to server sharing is not enabled on this server" : "На данном сервере выключено межсерверное предоставление общего доступа",
    "The mountpoint name contains invalid characters." : "Имя точки монтирования содержит недопустимые символы.",
    "Not allowed to create a federated share with the same user server" : "Не допускается создание федеративного общего ресурса с тем-же сервером пользователя",
    "Invalid or untrusted SSL certificate" : "Недействительный или недоверенный сертификат SSL",
    "Could not authenticate to remote share, password might be wrong" : "Не удалось произвести аутентификацию для доступа к удалённому хранилищу, возможно неправильно указан пароль",
    "Storage not valid" : "Хранилище недоступно",
    "Couldn't add remote share" : "Невозможно добавить удалённый общий ресурс",
    "Shared with you" : "Поделились с вами",
    "Shared with others" : "Доступные для других",
    "Shared by link" : "Доступные по ссылке",
    "Anonymous upload" : "Анонимная закачка",
    "Click to select files or use drag & drop to upload" : "Кликайте файлы для выбора и перетаскивайте дла закачки",
    "Uploaded files" : "Закачанные файлы",
    "Uploading..." : "Загрузка...",
    "Nothing shared with you yet" : "С вами пока ничем не поделились",
    "Files and folders others share with you will show up here" : "Здесь появятся файлы и каталоги, которыми с вами поделятся",
    "Nothing shared yet" : "Пока ничего не опубликовано",
    "Files and folders you share will show up here" : "Здесь появятся файлы и каталоги, которыми вы поделитесь",
    "No shared links" : "Нет общих ссылок",
    "Files and folders you share by link will show up here" : "Здесь появятся файлы и каталоги, ссылкой на которые вы поделитесь",
    "Do you want to add the remote share {name} from {owner}@{remote}?" : "Добавить удалённую общую папку {name} из {owner}@{remote}?",
    "Remote share" : "Удаленный общий ресурс",
    "Remote share password" : "Пароль для удаленного общего ресурса",
    "Cancel" : "Отменить",
    "Add remote share" : "Добавить удалённый общий ресурс",
    "You can upload into this folder" : "Вы можете загружать в эту папку",
    "No ownCloud installation (7 or higher) found at {remote}" : "На удаленном ресурсе {remote} не установлен ownCloud версии 7 или выше",
    "Invalid ownCloud url" : "Неверный адрес ownCloud",
    "Share" : "Общий доступ",
    "No expiration date set" : "Не установлен срок действия",
    "Shared by" : "Поделился",
    "Sharing" : "Общий доступ",
    "Share API is disabled" : "API общего доступа отключён",
    "Wrong share ID, share doesn't exist" : "Неверный идентификатор публикации, публикация не существует",
    "Could not delete share" : "Не удалось удалить публикацию",
    "Please specify a file or folder path" : "Пожалуйста, укажите путь к файлу или каталогу",
    "Wrong path, file/folder doesn't exist" : "Неверный путь, файл/каталог не существует",
    "Cannot remove all permissions" : "Не могу удалить все права",
    "Please specify a valid user" : "Пожалуйста, укажите допустимого пользователя",
    "Group sharing is disabled by the administrator" : "Общий доступ для групп отключён администратором",
    "Please specify a valid group" : "Пожалуйста, укажите допустимую группу",
    "Public link sharing is disabled by the administrator" : "Публикация через общие ссылки отключена администратором",
    "Public upload disabled by the administrator" : "Загрузка в общедоступную публикацию запрещена администратором",
    "Public upload is only possible for publicly shared folders" : "Общедоступная загрузка возможна только в папки с общим доступом",
    "Invalid date, date format must be YYYY-MM-DD" : "Неверная дата, формат даты должен быть ГГГГ-ММ-ДД",
    "Sharing %s failed because the back end does not allow shares from type %s" : "Не удалось поделиться %s, поскольку механизм удалённого обмена не разрешает публикации типа %s",
    "Unknown share type" : "Предоставление доступа неизвестного типа",
    "Not a directory" : "Это не каталог",
    "Could not lock path" : "Не удалось заблокировать путь",
    "Can't change permissions for public share links" : "Невозможно изменить права для публикации через ссылку",
    "Wrong or no update parameter given" : "Параметр для изменения неправилен или не задан",
    "Cannot increase permissions" : "Нельзя увеличить права",
    "A file or folder has been <strong>shared</strong>" : "<strong>Опубликован</strong> файл или каталог",
    "A file or folder was shared from <strong>another server</strong>" : "Файлом или каталогом поделились с <strong>удаленного сервера</strong>",
    "A public shared file or folder was <strong>downloaded</strong>" : "Общий файл или каталог был <strong>скачан</strong>",
    "You received a new remote share %2$s from %1$s" : "Вы получили новый удаленный общий ресурс %2$s от %1$s",
    "You received a new remote share from %s" : "%s поделился с вами удаленным общим ресурсом",
    "%1$s accepted remote share %2$s" : "%1$s принял удаленный общий ресурс %2$s",
    "%1$s declined remote share %2$s" : "%1$s отклонил удаленный общий ресурс %2$s",
    "%1$s unshared %2$s from you" : "%1$s закрыл для вас доступ к %2$s ",
    "Public shared folder %1$s was downloaded" : "Общий каталог %1$s был скачан",
    "Public shared file %1$s was downloaded" : "Общий файл %1$s, был скачан",
    "You shared %1$s with %2$s" : "Вы поделились %1$s с %2$s",
    "%2$s shared %1$s with %3$s" : "%2$s поделился %1$s с %3$s",
    "You removed the share of %2$s for %1$s" : "Вы удалили общий доступ к %2$s для %1$s",
    "%2$s removed the share of %3$s for %1$s" : "%2$s удалил общий доступ к %3$s для %1$s",
    "You shared %1$s with group %2$s" : "Вы поделились %1$s с группой %2$s",
    "%2$s shared %1$s with group %3$s" : "%2$s поделился %1$s с группой %3$s",
    "You removed the share of group %2$s for %1$s" : "Вы удалили общий доступ к группе %2$s для %1$s",
    "%2$s removed the share of group %3$s for %1$s" : "%2$s удалил общий доступ к группе %3$s для %1$s",
    "%2$s shared %1$s via link" : "%2$s поделился %1$s по ссылке",
    "You shared %1$s via link" : "Вы поделились %1$s с помощью ссылки",
    "You removed the public link for %1$s" : "Вы удалили публичную ссылку к %1$s",
    "%2$s removed the public link for %1$s" : "%2$s удалил публичную ссылку к %1$s",
    "Your public link for %1$s expired" : "Срок действия Вашей публичной ссылки к %1$s закончился",
    "The public link of %2$s for %1$s expired" : "Срок действия публичной ссылки к %2$s для %1$s закончился",
    "%2$s shared %1$s with you" : "%2$s поделился с вами %1$s",
    "%2$s removed the share for %1$s" : "%2$s удалил общий доступ к %1$s",
    "Downloaded via public link" : "Загружено по открытой ссылке",
    "Shared with %2$s" : "Поделился с %2$s",
    "Shared with %3$s by %2$s" : "Поделился %2$s с %3$s",
    "Removed share for %2$s" : "Удалён общий доступ к %2$s",
    "%2$s removed share for %3$s" : "%2$s удалил общий доступ к %3$s",
    "Shared with group %2$s" : "Поделился с группой %2$s",
    "Shared with group %3$s by %2$s" : "Поделился %2$s с группой %3$s",
    "Removed share of group %2$s" : "Удалён общий доступ к группе %2$s",
    "%2$s removed share of group %3$s" : "%2$s удалил общий доступ к группе %3$s",
    "Shared via link by %2$s" : "Поделился ссылкой %2$s",
    "Shared via public link" : "Поделился открытой ссылкой",
    "Removed public link" : "Удалена публичная ссылка",
    "%2$s removed public link" : "%2$s удалил публичную ссылку",
    "Public link expired" : "Срок действия публичной ссылки закончился",
    "Public link of %2$s expired" : "Срок действия публичной ссылки к %2$s закончился",
    "Shared by %2$s" : "Поделился %2$s",
    "Shares" : "События обмена файлами",
    "This share is password-protected" : "Общий ресурс защищен паролем",
    "The password is wrong. Try again." : "Неверный пароль. Попробуйте еще раз.",
    "Password" : "Пароль",
    "No entries found in this folder" : "Нет элементов в этом каталоге",
    "Name" : "Имя",
    "Share time" : "Дата публикации",
    "Expiration date" : "Дата окончания",
    "Sorry, this link doesn’t seem to work anymore." : "Эта ссылка устарела и более не действительна.",
    "Reasons might be:" : "Причиной может быть:",
    "the item was removed" : "элемент был удалён",
    "the link expired" : "срок действия ссылки истёк",
    "sharing is disabled" : "общий доступ отключён",
    "For more info, please ask the person who sent this link." : "Для получения дополнительной информации, свяжитесь с тем, кто отправил вам эту ссылку.",
    "%s is publicly shared" : "%s доступен публично",
    "Add to your ownCloud" : "Добавить в свой ownCloud",
    "Download" : "Скачать",
    "Download %s" : "Скачать %s",
    "Direct link" : "Прямая ссылка",
    "No permission to create share" : "Нет права на предоставление доступа",
    "Pending" : "Ожидается",
    "Accept" : "Принять",
    "Decline" : "Отклонить",
    "Declined" : "Отклонено",
    "An error occurred while updating share state: {message}" : "При обновлении состояния совместного доступа произошла ошибка: {message}",
    "Accept Share" : "Принять совместный доступ",
    "Decline Share" : "Отклонить совместный доступ",
    "Only recipient can change accepted state" : "Только получатель может изменить состояние принятости",
    "File sharing" : "Совместный доступ к файлам",
    "State" : "Состояние",
    "The group is blacklisted for sharing" : "Группа в чёрном списке для предоставления доступа",
    "Files Sharing" : "Предоставление доступа к файлам",
    "Exclude groups from receiving shares." : "Исключить группы из получения доступа.",
    "These groups will not receive shares. Members of the group can still send and receive shares outside of the group." : "Эти группы не  будут получать доступ. Члены группы всё-таки смогут предоставлять и получать доступ вне данной группы.",
    "Public link" : "Общедоступная ссылка",
    "Couldn't send mail to following recipient(s): %s " : "Не удалось отправить почту следующим получателям: %s ",
    "Group Sharing Blacklist" : "Чёрный список групп для общего доступа",
    "Exclude groups from receiving shares" : "Не давать группам получать общий доступ",
    "These groups will not be available to share with. Members of the group are not restricted in initiating shares and can receive shares with other groups they are a member of as usual." : "Для этих групп не будет возможности предоставить им общий доступ к чему-либо. Членам группы не ограничивается право предоставлять общий доступ от себя, и они могут получать общий доступ через другие группы, если являются их членами, в обычном порядке."
},
"nplurals=4; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<12 || n%100>14) ? 1 : n%10==0 || (n%10>=5 && n%10<=9) || (n%100>=11 && n%100<=14)? 2 : 3);");

==> owncloud-10.4.0.zip: owncloud/apps/files_sharing/l10n/ru.js <==
OC.L10N.register(
    "files_sharing",
    {
    "Server to server sharing is not enabled on this server" : "На данном сервере выключено межсерверное предоставление общего доступа",
    "The mountpoint name contains invalid characters." : "Имя точки монтирования содержит недопустимые символы.",
    "Not allowed to create a federated share with the same user server" : "Не допускается создание федеративного общего ресурса с тем-же сервером пользователя",
    "Invalid or untrusted SSL certificate" : "Недействительный или недоверенный сертификат SSL",
    "Could not authenticate to remote share, password might be wrong" : "Не удалось произвести аутентификацию для доступа к удалённому хранилищу, возможно неправильно указан пароль",
    "Storage not valid" : "Хранилище недоступно",
    "Couldn't add remote share" : "Невозможно добавить удалённый общий ресурс",
    "Shared with you" : "Поделились с вами",
    "Shared with others" : "Доступные для других",
    "Shared by link" : "Доступные по ссылке",
    "Anonymous upload" : "Анонимная закачка",
    "Click to select files or use drag & drop to upload" : "Кликайте файлы для выбора и перетаскивайте дла закачки",
    "Uploaded files" : "Закачанные файлы",
    "Uploading..." : "Загрузка...",
    "Nothing shared with you yet" : "С вами пока ничем не поделились",
    "Files and folders others share with you will show up here" : "Здесь появятся файлы и каталоги, которыми с вами поделятся",
    "Nothing shared yet" : "Пока ничего не опубликовано",
    "Files and folders you share will show up here" : "Здесь появятся файлы и каталоги, которыми вы поделитесь",
    "No shared links" : "Нет общих ссылок",
    "Files and folders you share by link will show up here" : "Здесь появятся файлы и каталоги, ссылкой на которые вы поделитесь",
    "An error occurred while updating share state: {message}" : "При обновлении состояния совместного доступа произошла ошибка: {message}",
    "Accept Share" : "Принять совместный доступ",
    "Decline Share" : "Отклонить совместный доступ",
    "Do you want to add the remote share {name} from {owner}@{remote}?" : "Добавить удалённую общую папку {name} из {owner}@{remote}?",
    "Remote share" : "Удаленный общий ресурс",
    "Remote share password" : "Пароль для удаленного общего ресурса",
    "Cancel" : "Отменить",
    "Add remote share" : "Добавить удалённый общий ресурс",
    "You can upload into this folder" : "Вы можете загружать в эту папку",
    "No ownCloud installation (7 or higher) found at {remote}" : "На удаленном ресурсе {remote} не установлен ownCloud версии 7 или выше",
    "Invalid ownCloud url" : "Неверный адрес ownCloud",
    "Share" : "Общий доступ",
    "No expiration date set" : "Не установлен срок действия",
    "Declined" : "Отклонено",
    "Pending" : "Ожидается",
    "Shared by" : "Поделился",
    "Sharing" : "Общий доступ",
    "A file or folder has been <strong>shared</strong>" : "<strong>Опубликован</strong> файл или каталог",
    "A file or folder was shared from <strong>another server</strong>" : "Файлом или каталогом поделились с <strong>удаленного сервера</strong>",
    "A public shared file or folder was <strong>downloaded</strong>" : "Общий файл или каталог был <strong>скачан</strong>",
    "You received a new remote share %2$s from %1$s" : "Вы получили новый удаленный общий ресурс %2$s от %1$s",
    "You received a new remote share from %s" : "%s поделился с вами удаленным общим ресурсом",
    "%1$s accepted remote share %2$s" : "%1$s принял удаленный общий ресурс %2$s",
    "%1$s declined remote share %2$s" : "%1$s отклонил удаленный общий ресурс %2$s",
    "%1$s unshared %2$s from you" : "%1$s закрыл для вас доступ к %2$s ",
    "Public shared folder %1$s was downloaded" : "Общий каталог %1$s был скачан",
    "Public shared file %1$s was downloaded" : "Общий файл %1$s, был скачан",
    "You shared %1$s with %2$s" : "Вы поделились %1$s с %2$s",
    "%2$s shared %1$s with %3$s" : "%2$s поделился %1$s с %3$s",
    "You removed the share of %2$s for %1$s" : "Вы удалили общий доступ к %2$s для %1$s",
    "%2$s removed the share of %3$s for %1$s" : "%2$s удалил общий доступ к %3$s для %1$s",
    "You unshared %1$s shared by %2$s from self" : "Вы убрали доступ к %1$s, предоставленный пользователем %2$s от себя",
    "You shared %1$s with group %2$s" : "Вы поделились %1$s с группой %2$s",
    "%2$s shared %1$s with group %3$s" : "%2$s поделился %1$s с группой %3$s",
    "You removed the share of group %2$s for %1$s" : "Вы удалили общий доступ к группе %2$s для %1$s",
    "%2$s removed the share of group %3$s for %1$s" : "%2$s удалил общий доступ к группе %3$s для %1$s",
    "%2$s shared %1$s via link" : "%2$s поделился %1$s по ссылке",
    "You shared %1$s via link" : "Вы поделились %1$s с помощью ссылки",
    "You removed the public link for %1$s" : "Вы удалили публичную ссылку к %1$s",
    "%2$s removed the public link for %1$s" : "%2$s удалил публичную ссылку к %1$s",
    "Your public link for %1$s expired" : "Срок действия Вашей публичной ссылки к %1$s закончился",
    "The public link of %2$s for %1$s expired" : "Срок действия публичной ссылки к %2$s для %1$s закончился",
    "%2$s shared %1$s with you" : "%2$s поделился с вами %1$s",
    "%2$s removed the share for %1$s" : "%2$s удалил общий доступ к %1$s",
    "Downloaded via public link" : "Загружено по открытой ссылке",
    "Shared with %2$s" : "Поделился с %2$s",
    "Shared with %3$s by %2$s" : "Поделился %2$s с %3$s",
    "Removed share for %2$s" : "Удалён общий доступ к %2$s",
    "%2$s removed share for %3$s" : "%2$s удалил общий доступ к %3$s",
    "Unshared %1$s from self" : "Отменён доступ к %1$s от себя",
    "Shared with group %2$s" : "Поделился с группой %2$s",
    "Shared with group %3$s by %2$s" : "Поделился %2$s с группой %3$s",
    "Removed share of group %2$s" : "Удалён общий доступ к группе %2$s",
    "%2$s removed share of group %3$s" : "%2$s удалил общий доступ к группе %3$s",
    "Shared via link by %2$s" : "Поделился ссылкой %2$s",
    "Shared via public link" : "Поделился открытой ссылкой",
    "Removed public link" : "Удалена публичная ссылка",
    "%2$s removed public link" : "%2$s удалил публичную ссылку",
    "Public link expired" : "Срок действия публичной ссылки закончился",
    "Public link of %2$s expired" : "Срок действия публичной ссылки к %2$s закончился",
    "Shared by %2$s" : "Поделился %2$s",
    "Shares" : "События обмена файлами",
    "File sharing" : "Совместный доступ к файлам",
    "Public link" : "Общедоступная ссылка",
    "Couldn't send mail to following recipient(s): %s " : "Не удалось отправить почту следующим получателям: %s ",
    "Share API is disabled" : "API общего доступа отключён",
    "Wrong share ID, share doesn't exist" : "Неверный идентификатор публикации, публикация не существует",
    "Could not delete share" : "Не удалось удалить публикацию",
    "Please specify a file or folder path" : "Пожалуйста, укажите путь к файлу или каталогу",
    "Wrong path, file/folder doesn't exist" : "Неверный путь, файл/каталог не существует",
    "Invalid date, date format must be YYYY-MM-DD" : "Неверная дата, формат даты должен быть ГГГГ-ММ-ДД",
    "Please specify a valid user" : "Пожалуйста, укажите допустимого пользователя",
    "Group sharing is disabled by the administrator" : "Общий доступ для групп отключён администратором",
    "Please specify a valid group" : "Пожалуйста, укажите допустимую группу",
    "The group is blacklisted for sharing" : "Группа в чёрном списке для предоставления доступа",
    "Public link sharing is disabled by the administrator" : "Публикация через общие ссылки отключена администратором",
    "Public upload disabled by the administrator" : "Загрузка в общедоступную публикацию запрещена администратором",
    "Public upload is only possible for publicly shared folders" : "Общедоступная загрузка возможна только в папки с общим доступом",
    "Sharing %s failed because the back end does not allow shares from type %s" : "Не удалось поделиться %s, поскольку механизм удалённого обмена не разрешает публикации типа %s",
    "Unknown share type" : "Предоставление доступа неизвестного типа",
    "Not a directory" : "Это не каталог",
    "Could not lock path" : "Не удалось заблокировать путь",
    "Could not update share" : "Не удалось обновить общий доступ",
    "Can't change permissions for public share links" : "Невозможно изменить права для публикации через ссылку",
    "Only recipient can change accepted state" : "Только получатель может изменить состояние принятости",
    "\"%1$s\" shared \"%3$s\" with you (on behalf of \"%2$s\")" : "Пользователь «%1$s» предоставил вам доступ к «%3$s» (от имени «%2$s»)",
    "\"%1$s\" shared \"%3$s\" with you" : "Пользователь «%1$s» предоставил вам доступ к «%3$s»",
    "\"%1$s\" invited you to view \"%3$s\" (on behalf of \"%2$s\")" : "Пользователь «%1$s» предлагает вам посмотреть «%3$s» (от имени «%2$s»)",
    "\"%1$s\" invited you to view \"%3$s\"" : "Пользователь «%1$s» предлагает вам посмотреть «%3$s»",
    "Accept" : "Принять",
    "Decline" : "Отклонить",
    "Automatically accept new incoming local user shares" : "Автоматически принимать новые входящие предоставления доступа от локальных пользователей",
    "This share is password-protected" : "Общий ресурс защищен паролем",
    "The password is wrong. Try again." : "Неверный пароль. Попробуйте еще раз.",
    "Password" : "Пароль",
    "No entries found in this folder" : "Нет элементов в этом каталоге",
    "Name" : "Имя",
    "State" : "Состояние",
    "Share time" : "Дата публикации",
    "Expiration date" : "Дата окончания",
    "Sorry, this link doesn’t seem to work anymore." : "Эта ссылка устарела и более не действительна.",
    "Reasons might be:" : "Причиной может быть:",
    "the item was removed" : "элемент был удалён",
    "the link expired" : "срок действия ссылки истёк",
    "sharing is disabled" : "общий доступ отключён",
    "For more info, please ask the person who sent this link." : "Для получения дополнительной информации, свяжитесь с тем, кто отправил вам эту ссылку.",
    "%s is publicly shared" : "%s доступен публично",
    "Download" : "Скачать",
    "Download %s" : "Скачать %s",
    "Direct link" : "Прямая ссылка",
    "Nothing to configure." : "Здесь настраивать нечего.",
    "Group Sharing Blacklist" : "Чёрный список групп для общего доступа",
    "Exclude groups from receiving shares" : "Не давать группам получать общий доступ",
    "These groups will not be available to share with. Members of the group are not restricted in initiating shares and can receive shares with other groups they are a member of as usual." : "Для этих групп не будет возможности предоставить им общий доступ к чему-либо. Членам группы не ограничивается право предоставлять общий доступ от себя, и они могут получать общий доступ через другие группы, если являются их членами, в обычном порядке."
},
"nplurals=4; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<12 || n%100>14) ? 1 : n%10==0 || (n%10>=5 && n%10<=9) || (n%100>=11 && n%100<=14)? 2 : 3);");
